@@ -41,6 +41,7 @@ def default_ctx():
         "max_cli_version": "0.10.33",
         "runs": {},
         "run_ids": [],
+        "file_names": [],
     }
 
 
@@ -371,7 +372,7 @@ def create_app(user_ctx=None):
                                     "displayName": "funky-town-13",
                                     "id": "test",
                                     "config": '{"epochs": {"value": 10}}',
-                                    "summaryMetrics": '{"acc": 10, "best_val_loss": 0.5}',
+                                    "summaryMetrics": '{"acc": 10, "best_val_loss": 0.5, "_wandb": {"runtime": 50}}',
                                     "logLineCount": 14,
                                     "historyLineCount": 15,
                                     "eventsLineCount": 0,
@@ -479,7 +480,21 @@ def create_app(user_ctx=None):
                                 "state": "running",
                                 "bestLoss": 0.33,
                                 "config": yaml.dump(
-                                    {"metric": {"name": "loss", "value": "minimize"}}
+                                    {
+                                        "controller": {"type": "local"},
+                                        "method": "random",
+                                        "parameters": {
+                                            "param1": {
+                                                "values": [1, 2, 3],
+                                                "distribution": "categorical",
+                                            },
+                                            "param2": {
+                                                "values": [1, 2, 3],
+                                                "distribution": "categorical",
+                                            },
+                                        },
+                                        "program": "train-dummy.py",
+                                    }
                                 ),
                                 "createdAt": datetime.now().isoformat(),
                                 "heartbeatAt": datetime.now().isoformat(),
@@ -659,7 +674,10 @@ def create_app(user_ctx=None):
                     "uploadHeaders": "",
                 },
             }
-            ctx["manifests_created"].append(manifest)
+            run_name = body.get("variables", {}).get("runName", "unknown")
+            run_ctx = ctx["runs"].setdefault(run_name, default_ctx())
+            for c in ctx, run_ctx:
+                c["manifests_created"].append(manifest)
             return {"data": {"createArtifactManifest": {"artifactManifest": manifest,}}}
         if "mutation UpdateArtifactManifest(" in body["query"]:
             manifest = {
@@ -864,6 +882,18 @@ def create_app(user_ctx=None):
             return os.urandom(size), 200
         # make sure to read the data
         request.get_data()
+        run_ctx = ctx["runs"].setdefault(run, default_ctx())
+        for c in ctx, run_ctx:
+            c["file_names"].append(request.args.get("file"))
+
+        inject = InjectRequestsParse(ctx).find(request=request)
+        if inject:
+            if inject.response:
+                response = inject.response
+            if inject.http_status:
+                # print("INJECT", inject, inject.http_status)
+                raise HttpException("some error", status_code=inject.http_status)
+
         if request.method == "PUT":
             curr = ctx["file_bytes"].get(file)
             if curr is None:
@@ -1283,6 +1313,10 @@ class ParseCTX(object):
     def run_ids(self):
         return self._ctx.get("run_ids", [])
 
+    @property
+    def file_names(self):
+        return self._ctx.get("file_names", [])
+
     @property
     def dropped_chunks(self):
         return self._ctx.get("file_stream", [{"dropped": 0}])[-1]["dropped"]
@@ -1290,7 +1324,7 @@ class ParseCTX(object):
     @property
     def summary_raw(self):
         fs_files = self.get_filestream_file_items()
-        summary = fs_files.get("wandb-summary.json", [])[-1]
+        summary = fs_files.get("wandb-summary.json", [{}])[-1]
         return summary
 
     @property
@@ -1300,7 +1334,12 @@ class ParseCTX(object):
     @property
     def summary(self):
         # TODO: move this to config_user eventually
-        return self.summary_raw
+        return {k: v for k, v in self.summary_raw.items() if k != "_wandb"}
+
+    @property
+    def summary_wandb(self):
+        # TODO: move this to config_user eventually
+        return self.summary_raw["_wandb"]
 
     @property
     def history(self):
